php.net |  support |  documentation |  report a bug |  advanced search |  search howto |  statistics |  random bug |  login
Return to Bug #75142
Patch buildcheck_php7.2rc0.patch revision 2017-08-31 23:11 UTC by zizzy at zizzy dot net

Patch buildcheck_php7.2rc0.patch for Compile Failure Bug #75142

Patch version 2017-08-31 23:11 UTC

Return to Bug #75142 | Download this patch
Patch Revisions:

Developer: zizzy@zizzy.net

--- buildcheck.sh.orig  2017-08-31 17:07:01.232586595 -0600
+++ buildcheck.sh       2017-08-31 17:07:35.661588477 -0600
@@ -28,18 +28,18 @@
   PHP_AUTOCONF='autoconf'
 fi

 # autoconf 2.59 or newer
 ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
 if test -z "$ac_version"; then
 echo "buildconf: autoconf not found."
-echo "           You need autoconf version 2.59 or newer installed"
+echo "           You need autoconf version 2.64 or newer installed"
 echo "           to build PHP from Git."
 exit 1
 fi
 IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "59" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "64" || test "$1" -lt "2"; then
 echo "buildconf: autoconf version $ac_version found."
-echo "           You need autoconf version 2.59 or newer installed"
+echo "           You need autoconf version 2.64 or newer installed"
 echo "           to build PHP from Git."
 exit 1
 else
@@ -28,18 +28,18 @@
 fi

-# autoconf 2.59 or newer
+# autoconf 2.64 or newer
 ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
 if test -z "$ac_version"; then
 
PHP Copyright © 2001-2024 The PHP Group
All rights reserved.
Last updated: Thu Apr 25 17:01:29 2024 UTC